==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/sw.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Umetengeneza timu {circle}",
    "{author} created the team {circle}" : "{author} ametengeneza timu {circle}",
    "You deleted {circle}" : "Umefuta {circle}",
    "{author} deleted {circle}" : "{author}amefuta  {circle}",
    "You made {member} join {circle}" : "Umefanya {member} kujiunga {circle}",
    "{author} made {member} join {circle}" : "{author} amefanya {member} kujiunga {circle}",
    "You added team {member} as member to {circle}" : "Umeongeza timu {member} kama mwanachama kwenye {circle}",
    "{author} added team {member} as member to {circle}" : "{author} ameongeza timu {member} kama mwanachama kwenye {circle}",
    "You made {member} leave {circle}" : "Umefanya {member} kuondoka {circle}",
    "{author} made {member} leave {circle}" : "{author} amefanya {member} kuondoka {circle}",
    "You removed {member} from {circle}" : "Umeondoa {member} kutoka {circle}",
    "{author} removed {member} from {circle}" : "{author} amemwondoa {member} kutoka {circle}",
    "You joined {circle}" : "Umejiunga {circle}",
    "{member} joined {circle}" : "{member} amejiunga {circle}",
    "You accepted the invitation to join {circle}" : "Ulikubali mwaliko wa kujiunga {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} alikubali mwaliko wa kujiunga {circle}",
    "You added {member} as member to {circle}" : "Umeongeza {member} kama mwanachama kwa {circle}",
    "You have been added as member to {circle} by {author}" : "Umeongezwa kama mwanachama {circle} na {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ameongezwa kama mwanachama {circle}na {author}",
    "You added {external} to {circle}" : "Umeongeza {external} kwa {circle}",
    "{external} has been added to {circle} by {author}" : "{external} imeongezwa kwa {circle} na {author}",
    "You accepted {member}'s request to join {circle}" : "Umekubali {member} ombi la kujiunga {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Ombi lako la kujiunga {circle} limekubaliwa na {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}ombi la kujiunga {circle} limekubaliwa na {author}",
    "You left {circle}" : "Umeondoka {circle}",
    "{member} left {circle}" : "{member} ameondoka {circle}",
    "You declined the invitation to join {circle}" : "Ulikataa mwaliko wa kujiunga {circle}",
    "{member} declined an invitation to join {circle}" : "{member} alikataa mwaliko wa kujiunga {circle}",
    "You cancelled your request to join {circle}" : "Umeghairi ombi lako la kujiunga {circle}",
    "{member} cancelled a request to join {circle}" : "{member}ameghairi ombi la kujiunga {circle}",
    "You have been removed from {circle} by {author}" : "Umeondolewa kutoka {circle} na {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ameondolewa kutoka {circle} na {author}",
    "You removed {external} from {circle}" : "Umeondoa {external} kutoka {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ameondolewa kutoka {circle} na {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Umeghairi {member} mwaliko wa kujiunga {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Mwaliko wako wa kujiunga {circle} imeghairiwa na {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ameghairi {member} mwaliko wa kujiunga {circle}",
    "You dismissed {member}'s request to join {circle}" : "Umekataa {member} ombi la kujiunga {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Ombi lako la kujiunga {circle} limekataliwa na {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} ombi la kujiunga {circle} limekataliwa na {author}",
    "You invited {member} to join {circle}" : "Umemwalika {member} kujiunga {circle}",
    "You have been invited to join {circle} by {author}" : "Umealikwa kujiunga {circle} na {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} amealikwa kujiunga {circle} na {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Umebadili{member} kiwango katika {circle} kwa %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} umebadilisha kiwango chako {circle} kwa %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} amebadili {member} kiwango katika {circle} kwa %1$s",
    "You sent a request to join {circle}" : "Ulituma ombi la kujiunga {circle}",
    "{member} sent a request to join {circle}" : "{member} alituma ombi la kujiunga {circle}",
    "You are the new owner of {circle}" : "Wewe ndiye mmiliki mpya wa {circle}",
    "{member} is the new owner of {circle}" : "{member}ndiye mmiliki mpya wa {circle}",
    "Teams" : "Timu",
    "On events happening in a <strong>team</strong> of which you are a member" : " Juu ya matukio yanayotokea katika <strong>timu</strong> ambayo wewe ni mwanachama",
    "Any important event in a <strong>team</strong> you are moderating" : "Tukio lolote muhimu katika <strong>timu</strong> unasimamia",
    "On global events happening in any <strong>team</strong>" : "Juu ya matukio ya kimataifa yanayotokea katika yoyote <strong>timu</strong>",
    "Single" : "Mtu mmoja",
    "Personal" : "Binafsi",
    "System" : "Mfumo",
    "Visible" : "Inayoonekana",
    "Open" : "Fungua",
    "Invite" : "Alika",
    "Join request" : "Ombi la kujiunga",
    "Friends" : "Marafiki",
    "Password protected" : "Nenosiri limelindwa",
    "No Owner" : "Hakuna mmiliki",
    "Hidden" : "Iliyofichwa",
    "Backend" : "Nyuma",
    "Local" : "Kawaida",
    "Root" : "Mzizi",
    "Team invite" : "Mwaliko wa timu",
    "Federated" : "Shirikisho",
    "Mount point" : "Sehemu ya kupachika",
    "Nextcloud Account" : "Akaunti ya Nextcloud ",
    "Nextcloud Group" : "Kundi la Nextcloud ",
    "Email address" : "Anwani ya barua pepe",
    "Contact" : "Mawasiliano",
    "Team" : "Timu",
    "Nextcloud App" : "Programu ya Nextcloud",
    "Teams App" : "Programu ya Timu",
    "Admin Command Line" : "Mstari wa Amri ya Msimamizi",
    "Member" : "Mwanachama",
    "Moderator" : "Msimamizi",
    "Admin" : "Msimamizi",
    "Owner" : "Mmiliki",
    "%s shared »%s« with you." : "%s imeshirikiwa »%s« na wewe.",
    "%s shared »%s« with \"%s\"." : "%s imeshirikiwa »%s« na \"%s\".",
    "%s on %s" : "%sjuu ya %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sameshiriki  »%2$s« na wewe.\nUnapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$sameshirikisha  »%2$s« na wewe. Unapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia.",
    "Password to access »%1$s« shared to you by %2$s" : "Nenosiri la kufikia »%1$s« limeshirikiwa kwako na %2$s",
    "Password to access »%s«" : "Nenosiri la kufikia »%s«",
    "It is protected with the following password:" : "Imelindwa na nenosiri lifuatalo:",
    "%1$s via %2$s" : "%1$s kupitia %2$s",
    "Click the button below to open it." : "Bofya kitufe kilicho hapa chini ili kuifungua.",
    "Open »%s«" : "Fungua >> 1%s <<",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s alishiriki faili nyingi nawe.\nUnapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo cha kuzifikia.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s alishiriki faili nyingi nawe. Unapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo cha kuzifikia.",
    "Password to access files shared to you by %1$s" : "Nenosiri la kufikia faili zilizoshirikiwa kwako na %1$s",
    "Password to access files" : " Nenosiri la kufikia faili",
    "%s shared multiple files with \"%s\"." : "%s imeshiriki faili nyingi na \"%s\".",
    "%s shared multiple files with you." : "%s alishiriki faili nyingi nawe. ",
    "Boot up" : "Anzisha",
    "Nextcloud Initialization" : "Uanzishaji wa Nextcloud ",
    "Circles App Initialization" : "Uanzishaji wa Programu ya Miduara",
    "Fresh installation status" : "Hali mpya ya ufungaji",
    "Building Local Database" : "Kujenga Hifadhidata ya Mitaa",
    "Adding local users and moderators" : "Kuongeza watumiaji wa ndani na wasimamizi",
    "Show all teams" : "Onesha timu zote",
    "Create a new team" : "Unda timu mpya",
    "Files" : "Mafaili",
    "The team is not federated" : "Timu haijashirikishwa",
    "You cannot join this team" : "Huwezi kujiunga na timu hii",
    "This member is not a moderator" : "Mwanachama huyu si msimamizi",
    "Insufficient privileges" : "Mapendeleo yasiyotosha",
    "This member does not exist" : "Mwanachama huyu hayupo",
    "This member is the owner of the team" : "Mwanachama huyu ndiye mmiliki wa timu",
    "Level cannot be changed for this type of member" : "Kiwango hakiwezi kubadilishwa kwa aina hii ya mwanachama",
    "%s (Team owned by %s)" : "%s (Timu inayomilikiwa na %s)",
    "You are now a member of the Team \"%2$s\"" : "Sasa wewe ni mwanachama wa Timu \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Umealikwa na %1$s kwenye Timu \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s alituma ombi la kuwa mwanachama wa Timu \"%2$s\"",
    "Accept" : "Kubali",
    "Refuse" : "Kataa",
    "Leave the team" : "Achana na timu",
    "%s" : "%s",
    "Personal team" : "Timu ya kibinafsi",
    "%s owned by %s" : "%s inamilikiwa na %s",
    "You have no permission to create a new team" : "Huna ruhusa ya kuunda timu mpya",
    "%s shared a file with \"%s\"." : "%s ameshiriki faili \"%s\".",
    "%s shared a file with you." : "%s ameshiriki faili na wewe.",
    "%1$s shared %2$s with %3$s" : "%1$s imeshirikiwa %2$s na %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s imeshirikiwa %2$s na \"%3$s\"",
    "Open %s" : "Fungua %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s alishiriki baadhi ya maudhui na wewe.\nUnapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s alishiriki baadhi ya maudhui na wewe. Unapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia. ",
    "Password to access content shared with you by %1$s" : "Nenosiri la kufikia maudhui yaliyoshirikiwa nawe %1$s",
    "Password to access content" : "Nenosiri la kufikia yaliyomo",
    "This item is already shared with this team" : "Kipengee hiki tayari kimeshirikiwa na timu hii",
    "Bring cloud-users closer together." : "Walete watumiaji wa cloud karibu pamoja.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Timu huruhusu watu kuunda vikundi vyao vya watu/wenzake/marafiki.\nVikundi hivyo vya watu vinaweza kutumiwa na programu nyingine yoyote kwa madhumuni ya kushiriki.",
    "Failed to load teams" : "Imeshindwa kupakia timu",
    "Try again" : "Jaribu tena",
    "No teams found" : "Hakuna timu zilizopatikana",
    "Join or create teams to see them here." : "Jiunge au uunde timu ili kuziona hapa.",
    "Create your first team" : "Unda timu yako ya kwanza",
    "Loading…" : "Inapakia",
    "More teams" : "Timu zaidi",
    "No files in here" : "Hakuna faili hapa",
    "No entries found in this folder" : "Hakuna maingizo yaliyopatikana katika kasha hili",
    "Name" : "Jina",
    "Size" : "Ukubwa",
    "Modified" : "Boresha",
    "Shared to Circles" : "Imeshirikiwa kwa Miduara",
    "Testing Basic Circle Creation" : "Kujaribu Uundaji wa Mduara wa Msingi",
    "This feature is not available for personal circles" : "Kipengele hiki hakipatikani kwa miduara ya kibinafsi",
    "You are already a member of this circle" : "Tayari wewe ni mwanachama wa mduara huu",
    "You have been blocked from this circle" : "Umezuiwa kutoka kwa mduara huu",
    "The account is already a member of this circle" : "Akaunti tayari ni mwanachama wa mduara huu",
    "The account has already been invited into this circle" : "Akaunti tayari imealikwa kwenye mduara huu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/sw.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Umetengeneza timu {circle}",
    "{author} created the team {circle}" : "{author} ametengeneza timu {circle}",
    "You deleted {circle}" : "Umefuta {circle}",
    "{author} deleted {circle}" : "{author}amefuta  {circle}",
    "You made {member} join {circle}" : "Umefanya {member} kujiunga {circle}",
    "{author} made {member} join {circle}" : "{author} amefanya {member} kujiunga {circle}",
    "You added team {member} as member to {circle}" : "Umeongeza timu {member} kama mwanachama kwenye {circle}",
    "{author} added team {member} as member to {circle}" : "{author} ameongeza timu {member} kama mwanachama kwenye {circle}",
    "You made {member} leave {circle}" : "Umefanya {member} kuondoka {circle}",
    "{author} made {member} leave {circle}" : "{author} amefanya {member} kuondoka {circle}",
    "You removed {member} from {circle}" : "Umeondoa {member} kutoka {circle}",
    "{author} removed {member} from {circle}" : "{author} amemwondoa {member} kutoka {circle}",
    "You joined {circle}" : "Umejiunga {circle}",
    "{member} joined {circle}" : "{member} amejiunga {circle}",
    "You accepted the invitation to join {circle}" : "Ulikubali mwaliko wa kujiunga {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} alikubali mwaliko wa kujiunga {circle}",
    "You added {member} as member to {circle}" : "Umeongeza {member} kama mwanachama kwa {circle}",
    "You have been added as member to {circle} by {author}" : "Umeongezwa kama mwanachama {circle} na {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ameongezwa kama mwanachama {circle}na {author}",
    "You added {external} to {circle}" : "Umeongeza {external} kwa {circle}",
    "{external} has been added to {circle} by {author}" : "{external} imeongezwa kwa {circle} na {author}",
    "You accepted {member}'s request to join {circle}" : "Umekubali {member} ombi la kujiunga {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Ombi lako la kujiunga {circle} limekubaliwa na {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}ombi la kujiunga {circle} limekubaliwa na {author}",
    "You left {circle}" : "Umeondoka {circle}",
    "{member} left {circle}" : "{member} ameondoka {circle}",
    "You declined the invitation to join {circle}" : "Ulikataa mwaliko wa kujiunga {circle}",
    "{member} declined an invitation to join {circle}" : "{member} alikataa mwaliko wa kujiunga {circle}",
    "You cancelled your request to join {circle}" : "Umeghairi ombi lako la kujiunga {circle}",
    "{member} cancelled a request to join {circle}" : "{member}ameghairi ombi la kujiunga {circle}",
    "You have been removed from {circle} by {author}" : "Umeondolewa kutoka {circle} na {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ameondolewa kutoka {circle} na {author}",
    "You removed {external} from {circle}" : "Umeondoa {external} kutoka {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ameondolewa kutoka {circle} na {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Umeghairi {member} mwaliko wa kujiunga {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Mwaliko wako wa kujiunga {circle} imeghairiwa na {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ameghairi {member} mwaliko wa kujiunga {circle}",
    "You dismissed {member}'s request to join {circle}" : "Umekataa {member} ombi la kujiunga {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Ombi lako la kujiunga {circle} limekataliwa na {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} ombi la kujiunga {circle} limekataliwa na {author}",
    "You invited {member} to join {circle}" : "Umemwalika {member} kujiunga {circle}",
    "You have been invited to join {circle} by {author}" : "Umealikwa kujiunga {circle} na {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} amealikwa kujiunga {circle} na {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Umebadili{member} kiwango katika {circle} kwa %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} umebadilisha kiwango chako {circle} kwa %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} amebadili {member} kiwango katika {circle} kwa %1$s",
    "You sent a request to join {circle}" : "Ulituma ombi la kujiunga {circle}",
    "{member} sent a request to join {circle}" : "{member} alituma ombi la kujiunga {circle}",
    "You are the new owner of {circle}" : "Wewe ndiye mmiliki mpya wa {circle}",
    "{member} is the new owner of {circle}" : "{member}ndiye mmiliki mpya wa {circle}",
    "Teams" : "Timu",
    "On events happening in a <strong>team</strong> of which you are a member" : " Juu ya matukio yanayotokea katika <strong>timu</strong> ambayo wewe ni mwanachama",
    "Any important event in a <strong>team</strong> you are moderating" : "Tukio lolote muhimu katika <strong>timu</strong> unasimamia",
    "On global events happening in any <strong>team</strong>" : "Juu ya matukio ya kimataifa yanayotokea katika yoyote <strong>timu</strong>",
    "Single" : "Mtu mmoja",
    "Personal" : "Binafsi",
    "System" : "Mfumo",
    "Visible" : "Inayoonekana",
    "Open" : "Fungua",
    "Invite" : "Alika",
    "Join request" : "Ombi la kujiunga",
    "Friends" : "Marafiki",
    "Password protected" : "Nenosiri limelindwa",
    "No Owner" : "Hakuna mmiliki",
    "Hidden" : "Iliyofichwa",
    "Backend" : "Nyuma",
    "Local" : "Kawaida",
    "Root" : "Mzizi",
    "Team invite" : "Mwaliko wa timu",
    "Federated" : "Shirikisho",
    "Mount point" : "Sehemu ya kupachika",
    "Nextcloud Account" : "Akaunti ya Nextcloud ",
    "Nextcloud Group" : "Kundi la Nextcloud ",
    "Email address" : "Anwani ya barua pepe",
    "Contact" : "Mawasiliano",
    "Team" : "Timu",
    "Nextcloud App" : "Programu ya Nextcloud",
    "Teams App" : "Programu ya Timu",
    "Admin Command Line" : "Mstari wa Amri ya Msimamizi",
    "Member" : "Mwanachama",
    "Moderator" : "Msimamizi",
    "Admin" : "Msimamizi",
    "Owner" : "Mmiliki",
    "%s shared »%s« with you." : "%s imeshirikiwa »%s« na wewe.",
    "%s shared »%s« with \"%s\"." : "%s imeshirikiwa »%s« na \"%s\".",
    "%s on %s" : "%sjuu ya %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sameshiriki  »%2$s« na wewe.\nUnapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$sameshirikisha  »%2$s« na wewe. Unapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia.",
    "Password to access »%1$s« shared to you by %2$s" : "Nenosiri la kufikia »%1$s« limeshirikiwa kwako na %2$s",
    "Password to access »%s«" : "Nenosiri la kufikia »%s«",
    "It is protected with the following password:" : "Imelindwa na nenosiri lifuatalo:",
    "%1$s via %2$s" : "%1$s kupitia %2$s",
    "Click the button below to open it." : "Bofya kitufe kilicho hapa chini ili kuifungua.",
    "Open »%s«" : "Fungua >> 1%s <<",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s alishiriki faili nyingi nawe.\nUnapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo cha kuzifikia.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s alishiriki faili nyingi nawe. Unapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo cha kuzifikia.",
    "Password to access files shared to you by %1$s" : "Nenosiri la kufikia faili zilizoshirikiwa kwako na %1$s",
    "Password to access files" : " Nenosiri la kufikia faili",
    "%s shared multiple files with \"%s\"." : "%s imeshiriki faili nyingi na \"%s\".",
    "%s shared multiple files with you." : "%s alishiriki faili nyingi nawe. ",
    "Boot up" : "Anzisha",
    "Nextcloud Initialization" : "Uanzishaji wa Nextcloud ",
    "Circles App Initialization" : "Uanzishaji wa Programu ya Miduara",
    "Fresh installation status" : "Hali mpya ya ufungaji",
    "Building Local Database" : "Kujenga Hifadhidata ya Mitaa",
    "Testing Basic Team Creation" : "Kujaribu Uundaji wa Timu ya Msingi",
    "Adding local users and moderators" : "Kuongeza watumiaji wa ndani na wasimamizi",
    "Show all teams" : "Onesha timu zote",
    "Create a new team" : "Unda timu mpya",
    "Files" : "Mafaili",
    "This feature is not available for personal teams" : "Kipengele hiki hakipatikani kwa timu za kibinafsi",
    "The team is not federated" : "Timu haijashirikishwa",
    "You cannot join this team" : "Huwezi kujiunga na timu hii",
    "This member is not a moderator" : "Mwanachama huyu si msimamizi",
    "Insufficient privileges" : "Mapendeleo yasiyotosha",
    "This member does not exist" : "Mwanachama huyu hayupo",
    "This member is the owner of the team" : "Mwanachama huyu ndiye mmiliki wa timu",
    "Level cannot be changed for this type of member" : "Kiwango hakiwezi kubadilishwa kwa aina hii ya mwanachama",
    "You are already a member of this team" : "Tayari wewe ni mwanachama wa timu hii",
    "You have been blocked from this team" : "Umezuiwa kutoka kwenye timu hii",
    "The account is already a member of this team" : "Akaunti tayari ni mwanachama wa timu hii",
    "The account has already been invited into this team" : "Akaunti tayari imealikwa katika timu hii",
    "%s (Team owned by %s)" : "%s (Timu inayomilikiwa na %s)",
    "You are now a member of the Team \"%2$s\"" : "Sasa wewe ni mwanachama wa Timu \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Umealikwa na %1$s kwenye Timu \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s alituma ombi la kuwa mwanachama wa Timu \"%2$s\"",
    "Accept" : "Kubali",
    "Refuse" : "Kataa",
    "Leave the team" : "Achana na timu",
    "%s" : "%s",
    "Personal team" : "Timu ya kibinafsi",
    "%s owned by %s" : "%s inamilikiwa na %s",
    "You have no permission to create a new team" : "Huna ruhusa ya kuunda timu mpya",
    "%s shared a file with \"%s\"." : "%s ameshiriki faili \"%s\".",
    "%s shared a file with you." : "%s ameshiriki faili na wewe.",
    "%1$s shared %2$s with %3$s" : "%1$s imeshirikiwa %2$s na %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s imeshirikiwa %2$s na \"%3$s\"",
    "Open %s" : "Fungua %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s alishiriki baadhi ya maudhui na wewe.\nUnapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s alishiriki baadhi ya maudhui na wewe. Unapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia. ",
    "Password to access content shared with you by %1$s" : "Nenosiri la kufikia maudhui yaliyoshirikiwa nawe %1$s",
    "Password to access content" : "Nenosiri la kufikia yaliyomo",
    "This item is already shared with this team" : "Kipengee hiki tayari kimeshirikiwa na timu hii",
    "Bring cloud-users closer together." : "Walete watumiaji wa cloud karibu pamoja.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Timu huruhusu watu kuunda vikundi vyao vya watu/wenzake/marafiki.\nVikundi hivyo vya watu vinaweza kutumiwa na programu nyingine yoyote kwa madhumuni ya kushiriki.",
    "Failed to load teams" : "Imeshindwa kupakia timu",
    "Try again" : "Jaribu tena",
    "No teams found" : "Hakuna timu zilizopatikana",
    "Join or create teams to see them here." : "Jiunge au uunde timu ili kuziona hapa.",
    "Create your first team" : "Unda timu yako ya kwanza",
    "Loading…" : "Inapakia",
    "More teams" : "Timu zaidi",
    "No files in here" : "Hakuna faili hapa",
    "No entries found in this folder" : "Hakuna maingizo yaliyopatikana katika kasha hili",
    "Name" : "Jina",
    "Size" : "Ukubwa",
    "Modified" : "Boresha",
    "Shared to Circles" : "Imeshirikiwa kwa Miduara"
},
"nplurals=2; plural=(n != 1);");
